@@ -1,21 +1,27 @@
 var indexSectionsWithContent =
 {
-  0: "_abdehpz",
-  1: "_adehpz",
-  2: "b"
+  0: "bde",
+  1: "bde",
+  2: "e",
+  3: "e",
+  4: "e"
 };
 
 var indexSectionNames =
 {
   0: "all",
   1: "classes",
-  2: "pages"
+  2: "files",
+  3: "functions",
+  4: "typedefs"
 };
 
 var indexSectionLabels =
 {
   0: "All",
   1: "Classes",
-  2: "Pages"
+  2: "Files",
+  3: "Functions",
+  4: "Typedefs"
 };
 
