@@ -31,29 +31,18 @@
 #include <string>
 #include <vector>
 
-static EnchantDict*
-MockProviderRequestEmptyMockDictionary(EnchantProvider *me, const char *)
+static int
+MockDictionaryCheck (EnchantDict * ,
+                     const char *const word,
+                     size_t len)
 {
-    EnchantDict* dict = enchant_broker_new_dict(me->owner);
-    dict->user_data = NULL;
-    dict->check = NULL;
-    dict->suggest = NULL;
-    dict->add_to_session = NULL;
-	
-    return dict;
+    return 1;
 }
 
-static void EmptyDictionary_ProviderConfiguration (EnchantProvider * me, const char *)
-{
-     me->request_dict = MockProviderRequestEmptyMockDictionary;
-     me->dispose_dict = MockProviderDisposeDictionary;
-}
-
-
 static char**
 MockDictionarySuggest (EnchantDict * , 
                        const char *const word,
-		               size_t len, 
+                       size_t len, 
                        size_t * out_n_suggs)
 {
     *out_n_suggs = 4;
@@ -74,12 +63,20 @@ MockDictionarySuggest (EnchantDict * ,
 static EnchantDict*
 MockProviderRequestBasicMockDictionary(EnchantProvider *me, const char *tag)
 {
-    
-    EnchantDict* dict = MockProviderRequestEmptyMockDictionary(me, tag);
+    EnchantDict* dict = enchant_dict_new(me, tag);
+    dict->user_data = NULL;
+    dict->check = MockDictionaryCheck;
     dict->suggest = MockDictionarySuggest;
+    dict->add_to_session = NULL;
+	
     return dict;
 }
 
+static void EmptyDictionary_ProviderConfiguration (EnchantProvider * me, const char *)
+{
+     me->request_dict = MockProviderRequestBasicMockDictionary;
+     me->dispose_dict = MockProviderDisposeDictionary;
+}
 
 static void BasicDictionary_ProviderConfiguration (EnchantProvider * me, const char *)
 {
@@ -161,7 +158,7 @@ struct EnchantDictionaryTestFixture : EnchantBrokerTestFixture
         return FileHasContents(GetExcludeDictFileName());
     }
 
-	bool BrokerPWLFileHasContents()
+    bool BrokerPWLFileHasContents()
     {
         return FileHasContents(_pwlFileName);
     }
